@@ -23,9 +23,10 @@ class SetupCog(commands.Cog):
         super().__init__()
 
     @commands.Cog.listener("on_message")
-    async def enable_function(self, message: discord.Message):
-        if self.enable_commands == False:
-            time.sleep(30)
+    async def enable_function(self, _: discord.Message):
+        """If not enabled, delay one second so dev can answer"""
+        if self.enable_commands is False:
+            time.sleep(2)
 
     @commands.command(name="sync")
     async def sync_command(self, context: commands.Context) -> None:
