@@ -61,3 +61,10 @@ TRELLO_APIKEY = secret_file.get("trello_apiKey")
 TRELLO_OAUTH_TOKEN = secret_file.get("trello_oauth_token")
 OPENAI_API_KEY = secret_file.get("openai_api_key")
 PHONECHECK_API_KEY = secret_file.get("phonecheck_api_key")
+
+RESPONSE_MESSAGES = [
+    "Hi {name}, we are open 11-7 Tu-Sa.",
+    "Hi {name}, your {product} is finished and ready for pickup any time 11-7 Tu-Sa.  See you soon",
+    "Hi {name}, your {product} is finished and ready for pickup any time 11-7 Tu-Sa.  The total is {total}.  See you soon.",
+    "Hi {name}, your {product} is finished and ready for pickup any time 11-7 Tu-Sa.  There is no charge.  See you soon.",
+]
